about summary refs log tree commit diff
path: root/compiler/rustc_const_eval/src/interpret
diff options
context:
space:
mode:
authorklensy <klensy@users.noreply.github.com>2023-11-13 14:43:53 +0300
committerklensy <klensy@users.noreply.github.com>2023-11-23 14:11:02 +0300
commitaff6c741d466610576b02fde72d139aa8c6ec0a8 (patch)
tree0f8154ef568be57bb4f5c611838a8a310942d81b /compiler/rustc_const_eval/src/interpret
parent38eecca62c73401043eb5ff01557bb58792631f7 (diff)
downloadrust-aff6c741d466610576b02fde72d139aa8c6ec0a8.tar.gz
rust-aff6c741d466610576b02fde72d139aa8c6ec0a8.zip
remove unused pub fn
Diffstat (limited to 'compiler/rustc_const_eval/src/interpret')
-rw-r--r--compiler/rustc_const_eval/src/interpret/projection.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/compiler/rustc_const_eval/src/interpret/projection.rs b/compiler/rustc_const_eval/src/interpret/projection.rs
index 6694c43c992..c8977aac0fc 100644
--- a/compiler/rustc_const_eval/src/interpret/projection.rs
+++ b/compiler/rustc_const_eval/src/interpret/projection.rs
@@ -256,13 +256,13 @@ where
     }
 
     /// Iterates over all fields of an array. Much more efficient than doing the
     /// same by repeatedly calling `operand_index`.
     pub fn project_array_fields<'a, P: Projectable<'tcx, M::Provenance>>(
         &self,
         base: &'a P,
     ) -> InterpResult<'tcx, ArrayIterator<'tcx, 'a, M::Provenance, P>> {
         let abi::FieldsShape::Array { stride, .. } = base.layout().fields else {
-            span_bug!(self.cur_span(), "operand_array_fields: expected an array layout");
+            span_bug!(self.cur_span(), "project_array_fields: expected an array layout");
         };
         let len = base.len(self)?;
         let field_layout = base.layout().field(self, 0);
@@ -256,13 +256,13 @@ where
 
     /// Iterates over all fields of an array. Much more efficient than doing the
-    /// same by repeatedly calling `operand_index`.
+    /// same by repeatedly calling `project_index`.
     pub fn project_array_fields<'a, P: Projectable<'tcx, M::Provenance>>(
         &self,